aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authoranthk <anthk@texto-plano.xyz>2021-03-25 16:05:59 +0000
committeranthk <anthk@texto-plano.xyz>2021-03-25 16:05:59 +0000
commit5b67e2cd6d47f97061e40e141dbaa9a0750092e4 (patch)
treec96a25ba865109c8551cb74a560a00433801c46b
parentbb30c94eedd4adc2402802c4096f4dbfd4f4addc (diff)
downloadbliper-es-5b67e2cd6d47f97061e40e141dbaa9a0750092e4.tar.gz
Iniciando castellanización de Bliper
-rw-r--r--LEEME110
-rw-r--r--Makefile18
-rw-r--r--bin/bliper-blog.pl6
-rw-r--r--bin/bliper-generate.pl100
-rw-r--r--bin/bliper-menu-creation.sh6
-rw-r--r--main-articles/2013-11-10-markdown-notes80
-rw-r--r--main-articles/2013-11-27-readme87
-rw-r--r--output/colors.css44
-rwxr-xr-xoutput/images/puffytron.jpgbin189788 -> 0 bytes
-rw-r--r--output/images/sample.pngbin83352 -> 0 bytes
-rw-r--r--output/style.css212
-rw-r--r--pages-b/readme-again77
-rw-r--r--pages/about12
-rw-r--r--pages/contact6
-rw-r--r--template/article-bottom20
-rw-r--r--template/article-top15
-rw-r--r--template/footer3
-rw-r--r--template/main-bottom1
-rw-r--r--template/main-top14
-rw-r--r--template/page-bottom20
-rw-r--r--template/page-top15
21 files changed, 175 insertions, 671 deletions
diff --git a/LEEME b/LEEME
new file mode 100644
index 0000000..b536899
--- /dev/null
+++ b/LEEME
@@ -0,0 +1,110 @@
+bliper (BLog engine In PERl) v0.2
+=================================
+
+Un script hecho en Perl que recoge todos los ficheros de principal/ como
+ficheros markdown y los recrea como archivos HTML en salida/ .
+También lee y genera páginas individuales que existan en los
+directorios paginas / y paginas-b/ .
+pages based on files that exist in pages/ and pages-b/ directory.
+
+Requiere: Text-Markdown (http://search.cpan.org/~bobtfish/Text-Markdown-1.000031/)
+
+Tambien genera un fichero index.html como la página principal con
+todos los enlaces a los posts y páginas que se generen.
+
+Los ficheros incluídos son:
+
+.
+|-- LICENSE
+|-- Makefile
+|-- README
+|-- TODO
+|-- bin
+| |-- bliper-blog.sh
+| |-- bliper-create-post.sh
+| |-- bliper-deploy.sh
+| |-- bliper-generate.pl
+| `-- bliper-menu-creation.sh
+|-- changelog
+|-- main-articles
+| |-- 2013-11-07-readme
+| `-- 2013-11-10-markdown-notes
+|-- output
+| |-- images
+| | `-- puffytron.jpg
+| `-- style.css
+|-- pages
+| |-- about
+| `-- contact
+|-- pages-b
+| `-- readme-again
+`-- template
+ |-- footer
+ |-- main-bottom
+ |-- main-top
+ |-- page-bottom
+ `-- page-top
+
+bin/bliper-blog.pl
+ simple script to check if posts exist in main-articles/. If no posts
+ exist, 'blog' page will not be created.
+
+bin/bliper-create-post.sh
+ use this instead of `touch <file>' for your posts. It just prepends `date
+ '+%Y-%m-%d'` to the beginning of the filename.
+
+bin/bliper-deploy.sh
+ is a script tha "deploys" the website. It's based on rsync and I've
+ included a sample config. Just change "user@host:/path/to/output" with
+ the real one.
+
+bin/bliper-generate.pl
+ is the main script that parses every post in input/ and recreates it as
+ HTML in output/. It also creates the index.html page and appends all links
+ to posts.
+
+bin/bliper-menu-creation.sh
+ upon generation, a file called 'tmp' gets created. Then, this script
+ comes and replaces all "INSERTMENU" strings in templates with the real
+ menu. Nothing fancy, but you need to run this before deployment or
+ viewing to generate your menus in all pages.
+
+main-articles
+ files in this directory will be linked in 'blog' page. If no articles
+ exist, blog page will not be created.
+
+Makefile
+ just type 'make' to generate your site. It calls bin/bliper-generate.pl
+ and bin/bliper-menu-creation.sh. When you edit your
+ bin/bliper-deploy.sh, you can deploy your site with 'make deploy'.
+ Possible options are: make, make clean, make deploy.
+
+output
+ is the directory which all generated pages are placed. Edit the style.css
+ file according to your needs.
+
+pages
+ is the directory where all individual pages live (check the included
+ sample).
+
+pages-b
+ is the directory which produces pages that do not appear on the menu.
+ You can link to them through other pages with markdown.
+
+template
+ main-top is the top section of the main page.
+ main-bottom is the bottom section of the main page.
+ page-top is a generic template for the top section of any post page.
+ page-bottom is a generic template for the bottom section of any post page.
+ footer is just the footer appended in all pages.
+
+To view the demo, run `make` in your main bliper directory. This calls
+bin/bliper-generate.pl and bin/bliper-menu-creation.sh. If you need to view the
+results, just run `$BROWSER output/index.html`
+
+When your site is ready, edit `bin/bliper-deploy.sh` accordingly and just `make
+deploy` on your main bliper directory.
+
+There is also support for disqus individualy for pages and articles. Just
+uncomment the disqus section on template/article-bottom and/or
+template/pate-bottom to enable disqus on articles and/or pages.
diff --git a/Makefile b/Makefile
index fa5eeb7..c9e1d7f 100644
--- a/Makefile
+++ b/Makefile
@@ -1,21 +1,21 @@
-all: blog.create bliper.create menu.create
+all: crear.blog crear.bliper crear.menu
-blog.create:
+crear.blog:
@exec perl bin/bliper-blog.pl
-bliper.create:
+crear.bliper:
@exec perl bin/bliper-generate.pl
-menu.create:
+crear.menu:
@echo ""
- @echo "Generating menu in the following pages:"
+ @echo "Generando el menu en las siguientes páginas:"
@exec sh bin/bliper-menu-creation.sh
clean:
- @echo "Cleaning out generated pages"
- rm output/*.html
- rm output/tmp
+ @echo "Limpiando las páginas generadas:"
+ rm salida/*.html
+ rm salida/tmp
deploy:
- @echo "Deploying website"
+ @echo "Poniendo la web a disposición del servidor:"
@sh bin/bliper-deploy.sh
diff --git a/bin/bliper-blog.pl b/bin/bliper-blog.pl
index 4561465..29173fb 100644
--- a/bin/bliper-blog.pl
+++ b/bin/bliper-blog.pl
@@ -5,10 +5,10 @@ use Cwd;
my $maindir = getcwd;
my $blogdir = 'output/blog.html';
-my $articledir = 'main-articles';
+my $articledir = 'articulos';
my $count = 0;
-unlink "pages/blog.md";
+unlink "paginas/blog.md";
opendir(my $dh, $articledir) or die "opendir($articledir): $!";
while (my $de = readdir($dh)) {
@@ -20,7 +20,7 @@ if ($count gt 0) {
chdir($articledir) or die "Can't change dir to $articledir $!\n";
my @files = <*>;
@files = reverse @files;
- open (OUT, '>>', "../pages/blog.md") or die "Could not open blog file $!\n";
+ open (OUT, '>>', "../paginas/blog.md") or die "Could not open blog file $!\n";
foreach my $file (@files) {
$file =~ s/\.[^\.]*$//;
print OUT "<a class=\"blogitem\" href=\"$file.html\">$file</a><br>";
diff --git a/bin/bliper-menu-creation.sh b/bin/bliper-menu-creation.sh
index f38f113..55a9c44 100644
--- a/bin/bliper-menu-creation.sh
+++ b/bin/bliper-menu-creation.sh
@@ -1,13 +1,13 @@
#!/bin/sh
-MENU=`cat output/tmp`
-FILES=output
+MENU=`cat salida/tmp`
+FILES=salida
cd $FILES
for f in *.html
do
- echo "Processing $f"
+ echo "Procesando $f"
sed -e "s#%INSERTMENU%#$MENU#g" $f > $f.new
mv $f.new $f
done
diff --git a/main-articles/2013-11-10-markdown-notes b/main-articles/2013-11-10-markdown-notes
deleted file mode 100644
index 476bb0f..0000000
--- a/main-articles/2013-11-10-markdown-notes
+++ /dev/null
@@ -1,80 +0,0 @@
-### Markdown semantics
-
-
-#### This section covers some basic Markdown syntax.
-
-Paragraphs, headers, blockquotes
-
-markdown:
-
- A First Level Header
- ====================
-
- A Second Level Header
- ---------------------
-
- Now is the time for all good men to come to
- the aid of their country. This is just a
- regular paragraph.
-
- The quick brown fox jumped over the lazy
- dog's back.
-
- ### Header 3
-
- > This is a blockquote.
- >
- > This is the second paragraph in the blockquote.
- >
- > ## This is an H2 in a blockquote
-
-Phrase emphasis
-
-markdown:
-
- Some of these words *are emphasized*.
- Some of these words _are emphasized also_.
-
- Use two asterisks for **strong emphasis**.
- Or, if you prefer, __use two underscores instead__.
-
-output:
-
- <p>Some of these words <em>are emphasized</em>.
- Some of these words <em>are emphasized also</em>.</p>
-
- <p>Use two asterisks for <strong>strong emphasis</strong>.
- Or, if you prefer, <strong>use two underscores instead</strong>.</p>
-
-Links
-
-markdown:
-
- This is an [example link](http://example.com/).
-
-
- I get 10 times more traffic from [Google][1] than from
- [Yahoo][2] or [MSN][3].
-
- [1]: http://google.com/ "Google"
- [2]: http://search.yahoo.com/ "Yahoo Search"
- [3]: http://search.msn.com/ "MSN Search"
-
-Images
-
-markdown:
-
- ![alt text](/path/to/img.jpg "Title")
-
-
-Code
-
-markdown:
-just ident 1tab/4spaces the block you want to display as code
-
-#### How to run
-
-Demo complete, cookie time.
-
-![wallpaper](images/puffytron.jpg "OpenBSD")
-[wallpaper](images/puffytron.jpg)
diff --git a/main-articles/2013-11-27-readme b/main-articles/2013-11-27-readme
deleted file mode 100644
index eb0bf28..0000000
--- a/main-articles/2013-11-27-readme
+++ /dev/null
@@ -1,87 +0,0 @@
-bliper (BLog engine In PERl) v0.2
-=================================
-
-A perl script that reads all posts from main-articles/ as markdown and creates
-them as HTML articles in output/ dir. It also reads and creates individual
-pages based on files that exist in pages/ and pages-b/ directory.
-
-Deps: Text-Markdown (http://search.cpan.org/~bobtfish/Text-Markdown-1.000031/)
-
-It also creates a main page as index.html with all links to posts and pages
-generated.
-
-Files included are:
-
- .
- |-- LICENSE
- |-- README
- |-- TODO
- |-- bin
- | |-- bliper-blog.sh
- | |-- bliper-create-post.sh
- | |-- bliper-deploy.sh
- | |-- bliper-generate.pl
- | `-- bliper-menu-creation.sh
- |-- main-articles
- | |-- 2013-11-07-readme
- | `-- 2013-11-10-markdown-notes
- |-- Makefile
- |-- output
- | |-- images
- | | `-- puffytron.jpg
- | `-- style.css
- |-- pages
- | |-- about
- | `-- contact
- |-- pages-b
- | `-- readme-again
- `-- template
- |-- footer
- |-- main-bottom
- |-- main-top
- |-- page-bottom
- `-- page-top
-
-_bin/bliper-blog.pl_
- simple script to check if posts exist in main-articles/. If no posts exist, 'blog' page will not be created.
-
-_bin/bliper-create-post.sh_
- use this instead of `touch <file>` for your posts. It just prepends `date '+%Y-%m-%d'` to the beginning of the filename.
-
-_bin/bliper-deploy.sh_
- is a script tha "deploys" the website. It's based on rsync and I've included a sample config. Just change "user@host:/path/to/output" with the real one.
-
-_bin/bliper-generate.pl_
- is the main script that parses every post in input/ and recreates it as HTML in output/. It also creates the index.html page and appends all links to posts.
-
-_bin/bliper-menu-creation.sh_
- upon generation, a file called 'tmp' gets created. Then, this script comes and replaces all "insertmenu" (in capital) strings in templates with the real menu. Nothing fancy, but you need to run this before deployment or viewing to generate your menus in all pages.
-
-_main-articles_
- files in this directory will be linked in 'blog' page. If no articles exist, blog page will not be created.
-
-_Makefile_
- just type 'make' to generate your site. It calls bin/bliper-generate.pl and bin/bliper-menu-creation.sh. When you edit your bin/bliper-deploy.sh, you can deploy your site with 'make deploy'. Possible options are: make, make clean, make deploy.
-
-_output_
- is the directory which all generated pages are placed. Edit the style.css file according to your needs.
-
-_pages_
- is the directory where all individual pages live (check the included sample).
-
-_pages-b_
- is the directory which produces pages that do not appear on the menu. You can link to them through other pages with markdown.
-
-_template_
- main-top is the top section of the main page.
- main-bottom is the bottom section of the main page.
- page-top is a generic template for the top section of any post page.
- page-bottom is a generic template for the bottom section of any post page. footer is just the footer appended in all pages.
-
-To view the demo, run `make` in your main bliper directory. This calls bin/bliper-generate.pl and bin/bliper-menu-creation.sh. If you need to view the results, just run `$BROWSER output/index.html`
-
-When your site is ready, edit `bin/bliper-deploy.sh` accordingly and just `make deploy` on your main bliper directory.
-
-There is also support for disqus individualy for pages and articles. Just uncomment the disqus section on template/article-bottom and/or template/pate-bottom to enable disqus on articles and/or pages.
-
-[This](readme-again.html) is a test to a page that came from pages-b.
diff --git a/output/colors.css b/output/colors.css
deleted file mode 100644
index cbe95e0..0000000
--- a/output/colors.css
+++ /dev/null
@@ -1,44 +0,0 @@
-body {
- background-color: #efefef;
-}
-
-.container {
- color: #666;
-}
-
-.menu, .menu li a, footer {
- color: #a7a9ac;
-}
-
-.menu li a:hover, .menu li a.current, a:hover, a, a em, h1, h2, h3, h4, h5 {
- color: #0091d0;
-}
-
-a:hover {
- color: #a7a9ac;
-}
-
-a em:hover {
- color: #000;
-}
-
-code {
- color: #333;
- background-color: #e0e0e0;
-}
-
-
-#disqus_thread {
- color: #e3e3e3;
-}
-
-pre, pre code {
- color: #333;
- background-color: #e0e0e0;
-}
-
-@media screen and (max-width: 480px) {
- a {
- color: #0091d0;
- }
-}
diff --git a/output/images/puffytron.jpg b/output/images/puffytron.jpg
deleted file mode 100755
index d21053f..0000000
--- a/output/images/puffytron.jpg
+++ /dev/null
Binary files differ
diff --git a/output/images/sample.png b/output/images/sample.png
deleted file mode 100644
index ccce66f..0000000
--- a/output/images/sample.png
+++ /dev/null
Binary files differ
diff --git a/output/style.css b/output/style.css
deleted file mode 100644
index b72d064..0000000
--- a/output/style.css
+++ /dev/null
@@ -1,212 +0,0 @@
-@import "colors.css";
-
-html {
- overflow-y: scroll;
-}
-
-body {
- font-family: sans-serif;
- font-size: 1em;
-}
-
-.container {
- max-width: 680px;
- margin: 0 auto;
-}
-
-.upstart {
- clear: both;
- text-align: right;
-}
-
-/* menu */
-.menu {
- line-height: 1.5em;
- text-align: center;
-}
-
-.menu li {
- display: inline;
- padding: 0 4px;
-}
-
-.menu li a {
- text-decoration: none;
- padding: 0.3em;
- border-top: 0.5ex solid #a7a9ac;
- margin-right: 5px;
- margin-left: -5px;
-}
-
-.menu li a:hover, .menu li a.current {
- border-top: 0.5ex solid #0091d0;
-}
-
-h1, h2, h3, h4, h5 {
- font-weight: normal;
-}
-
-h1 {
- font-size: 1.8em;
-}
-
-h3 {
- margin-top: 30px;
-}
-
-.latart {
- text-align: center;
-}
-
-a, a:hover {
- text-decoration: underline;
-}
-
-a em {
- font-size: 0.9em;
-}
-
-.previewlink {
- text-decoration: none;
- text-align: right;
- display: block;
-}
-
-.previewlink:hover {
- text-decoration: underline;
-}
-
-.preview {
- border: 1px solid #c0c0c0;
- padding: 5px 20px;
- position: relative;
- margin: 0 auto;
- transition: background-color 400ms linear;
-}
-
-.preview:hover {
- background: #e3e3e3;
-}
-
-a.indexlink {
- line-height: 2em;
-}
-
-p {
- max-width: 680px;
- white-space: normal;
- line-height: 1.6em;
- text-align: justify;
-}
-
-.preview p {
- margin-top: 0em;
- margin-bottom: 0em;
-}
-
-.container ul li {
- /* list-style: none; */
-}
-
-.container ul li:before {
- /* content: "\2192"; */
- /* float: left; */
-}
-
-pre {
- font-family: monospace;
- border: 1px solid #c0c0c0;
- padding: 5px;
- max-width: 680px;
- word-wrap: break-word;
- white-space: pre-wrap;
- overflow-x: auto;
-}
-
-p code, li code {
- border: 1px solid #c0c0c0;
- max-width: 680px;
- padding: 0.3em;
- margin: 0.3em;
- word-wrap: break-word;
- white-space: pre-wrap;
-}
-
-code {
- font-family: Monaco, Consolas, "Courier New", monospace;
- font-size: 13px;
-}
-
-.logo {
- border: none;
- display: block;
- margin-left: auto;
- margin-right: auto;
- margin-bottom: 70px;
-}
-
-img {
- margin-top: 20px;
- max-width: 100%;
- height: auto;
-}
-
-li {
- line-height: 1.6em;
- text-align: justify;
-}
-
-hr {
- width: 300%;
- margin-left: -40%;
- margin-top: 40px;
-}
-
-blockquote {
- margin: 10px 0 10px 50px;
- padding-left: 15px;
- border-left: 3px solid #ccc;
-}
-
-footer {
- max-width: 100%;
- text-align: center;
- margin: 2em auto 0 auto;
- padding-top: 2em;
- padding-bottom: 3em;
- border-top: 1px solid #c0c0c0;
-}
-
-#disqus_thread {
- max-width: 680px;
- margin: 0 auto;
-}
-
-@media screen and (min-width: 481px) {
- .menu {
- margin-left: -30px;
- }
-}
-
-@media screen and (max-width: 480px) {
- .menu li {
- display: list-item;
- margin-left: -40px;
- list-style: none;
- text-align: center;
- padding-top: 10px;
- text-transform: uppercase;
- }
-
- .menu li a {
- border: none;
- }
-
- .menu li a:hover {
- border: none;
- }
-
- a em {
- font-size: 1em;
- }
-}
diff --git a/pages-b/readme-again b/pages-b/readme-again
deleted file mode 100644
index 0cbb2d2..0000000
--- a/pages-b/readme-again
+++ /dev/null
@@ -1,77 +0,0 @@
-bliper (BLog engine In PERl) v0.2
-=================================
-
-A perl script that reads all posts from main-articles/ as markdown and creates
-them as HTML articles in output/ dir. It also reads and creates individual
-pages based on files that exist in pages/ directory.
-
-Deps: Text-Markdown (http://search.cpan.org/~bobtfish/Text-Markdown-1.000031/)
-
-It also creates a main page as index.html with all links to posts and pages
-generated.
-
-Files included are:
-
- .
- |-- LICENSE
- |-- README
- |-- TODO
- |-- bin
- | |-- bliper-create-post.sh
- | |-- bliper-deploy.sh
- | |-- bliper-generate.pl
- | `-- bliper-menu-creation.sh
- |-- main-articles
- | |-- 2013-11-07-readme
- | `-- 2013-11-10-markdown-notes
- |-- output
- | |-- images
- | | `-- puffytron.jpg
- | `-- style.css
- |-- pages
- | |-- about
- | `-- contact
- `-- template
- |-- footer
- |-- main-bottom
- |-- main-top
- |-- page-bottom
- `-- page-top
-
-_bin/bliper-create-post.sh_
- use this instead of `touch <file>` for your posts. It just prepends `date '+%Y-%m-%d'` to the beginning of the filename.
-
-_bin/bliper-deploy.sh_
- is a script tha "deploys" the website. It's based on rsync and I've
- included a sample config. Just change "user@host:/path/to/output" with
- the real one.
-
-_bin/bliper-generate.pl_
- is the main script that parses every post in input/ and recreates it as
- HTML in output/. It also creates the index.html page and appends all links
- to posts.
-
-_bin/bliper-menu-creation.sh_
- upon generation, a file called 'tmp' gets created. Then, this script
- replaces all "insertmenu"(in capital) strings in templates with the
- real menu. Nothing fancy, but you need to run this before deployment or
- viewing to generate your menus in all pages.
-
-_main-articles_
- is the directory which serves as the place to create all posts in markdown.
-
-_output_
- is the directory which all generated pages are placed. Edit the style.css
- file according to your needs.
-
-_pages_
- is the directory which produced all new pages (again, sample included).
-
-_template_
- main-top is the top section of the main page.
- main-bottom is the bottom section of the main page.
- page-top is a generic template for the top section of any post page.
- page-bottom is a generic template for the bottom section of any post page.
- footer is just the footer appended in all pages.
-
-I've included a demo file in input/markdown-notes. Just run `bliper-generate.pl` in your main directory, `bliper-menu-creation.sh` and `$BROWSER output/index.html` to see the demo. There is also the option to rsync the files to your server with `bliper-deploy.sh`
diff --git a/pages/about b/pages/about
deleted file mode 100644
index 8d6647a..0000000
--- a/pages/about
+++ /dev/null
@@ -1,12 +0,0 @@
-About
-=====
-
-This is an about demo page.
-
-orem ipsum dolor sit amet, consectetur adipiscing elit. In ultrices orci sit amet diam semper tincidunt. Duis mi augue, egestas in laoreet nec, iaculis vitae libero. Cras at convallis lorem, euismod sagittis mi. Integer lorem elit, pulvinar eget dui a, consectetur posuere quam. Proin eu fringilla mi. Integer tempus, nunc at imperdiet volutpat, augue metus suscipit neque, eu elementum sapien nulla eget quam. Donec et aliquam nunc.
-
-#### H4 header
-
-Nulla tortor dolor, convallis sit amet libero ac, iaculis vulputate libero. Proin convallis sagittis ipsum, nec dictum massa pharetra non. Phasellus congue ligula nec sem lacinia, ac convallis est suscipit. Nam laoreet euismod turpis, placerat condimentum augue condimentum nec. Vestibulum libero sem, lacinia tincidunt cursus id, sollicitudin at nibh. Ut ullamcorper consectetur sollicitudin. Fusce porta enim dapibus leo condimentum, blandit convallis tellus eleifend. Fusce ac orci lacus. Donec accumsan laoreet purus, at venenatis elit. Sed tempus, leo sit amet scelerisque rutrum, enim magna ornare est, quis iaculis tellus lorem eu nibh. Curabitur dapibus, tortor sed tristique imperdiet, ante erat rhoncus tortor, interdum volutpat nibh urna et neque. Phasellus ornare lectus quis nibh semper vulputate.
-
-Cras dictum, urna non condimentum ultrices, velit odio facilisis leo, id tempus neque velit tristique mauris. Aenean mattis lacus nisl, eu molestie libero accumsan in. Duis pulvinar turpis at blandit consequat. Quisque et nibh sit amet enim dignissim facilisis in eget ipsum. Aliquam velit erat, dignissim ut lacus vel, aliquet sagittis lacus. Mauris consectetur tempus nibh vehicula bibendum. Proin sed tellus sapien. Proin lobortis vehicula lobortis. Phasellus ullamcorper quis tortor a laoreet. Curabitur et mi tortor. Etiam interdum enim ut quam auctor, ac ultrices metus tempus. Suspendisse semper dolor vel consequat consectetur. Cras tristique velit sit amet viverra posuere. Curabitur a vehicula justo, eget egestas enim. Mauris sit amet nulla vehicula, tempor velit sit amet, dignissim purus.
diff --git a/pages/contact b/pages/contact
deleted file mode 100644
index 82184b9..0000000
--- a/pages/contact
+++ /dev/null
@@ -1,6 +0,0 @@
-Contact
-=======
-
-#### H4 header
-
-This is a sample contact page. Nothing to see here, move along.
diff --git a/template/article-bottom b/template/article-bottom
deleted file mode 100644
index 925eb9c..0000000
--- a/template/article-bottom
+++ /dev/null
@@ -1,20 +0,0 @@
-<a href="#start"><p class="upstart">^</p></a>
-</div> <!-- container end -->
-<!-- uncomment to use disqus. Remember to change <example> to shortname
-<div id="disqus_thread"></div>
-<script type="text/javascript">
- /* * * CONFIGURATION VARIABLES: EDIT BEFORE PASTING INTO YOUR WEBPAGE * * */
- var disqus_shortname = '<example>'; // Required - Replace example with your forum shortname
-
- /* * * DON'T EDIT BELOW THIS LINE * * */
- (function() {
- var dsq = document.createElement('script'); dsq.type = 'text/javascript'; dsq.async = true;
- dsq.src = '//' + disqus_shortname + '.disqus.com/embed.js';
- (document.getElementsByTagName('head')[0] || document.getElementsByTagName('body')[0]).appendChild(dsq);
- })();
-</script>
-<noscript>Please enable JavaScript to view the <a href="http://disqus.com/?ref_noscript">comments powered by Disqus.</a></noscript>
- disqus -->
-<footer>Made with vim and generated by bliper in Perl.</footer>
-</body>
-</html>
diff --git a/template/article-top b/template/article-top
deleted file mode 100644
index ab3ee9d..0000000
--- a/template/article-top
+++ /dev/null
@@ -1,15 +0,0 @@
-<!DOCTYPE HTML>
-<html>
-<head>
- <meta charset="utf-8">
- <meta name="viewport" content="width=device-width">
- <title>Bliper</title>
- <link href="style.css" rel="stylesheet" type="text/css" />
-</head>
-<body>
-<div class="header">
- <a name="start"></a>
- <a href="index.html"><img class="logo" src="images/sample.png" /></a>
-%INSERTMENU%
-</div>
-<div class="container"> <!-- container begin -->
diff --git a/template/footer b/template/footer
deleted file mode 100644
index 8c5137b..0000000
--- a/template/footer
+++ /dev/null
@@ -1,3 +0,0 @@
-<footer>Made with vim and generated by bliper in Perl.</footer>
-</body>
-</html>
diff --git a/template/main-bottom b/template/main-bottom
deleted file mode 100644
index 3b96b9e..0000000
--- a/template/main-bottom
+++ /dev/null
@@ -1 +0,0 @@
-</div> <!-- container end -->
diff --git a/template/main-top b/template/main-top
deleted file mode 100644
index 7bd8967..0000000
--- a/template/main-top
+++ /dev/null
@@ -1,14 +0,0 @@
-<!DOCTYPE HTML>
-<html>
-<head>
- <meta charset="utf-8">
- <meta name="viewport" content="width=device-width">
- <title>Bliper</title>
- <link href="style.css" rel="stylesheet" type="text/css" />
-</head>
-<body>
-<div class="header">
- <a href="index.html"><img class="logo" src="images/sample.png" /></a>
-%INSERTMENU%
-</div>
-<div class="container"> <!-- container begin -->
diff --git a/template/page-bottom b/template/page-bottom
deleted file mode 100644
index 925eb9c..0000000
--- a/template/page-bottom
+++ /dev/null
@@ -1,20 +0,0 @@
-<a href="#start"><p class="upstart">^</p></a>
-</div> <!-- container end -->
-<!-- uncomment to use disqus. Remember to change <example> to shortname
-<div id="disqus_thread"></div>
-<script type="text/javascript">
- /* * * CONFIGURATION VARIABLES: EDIT BEFORE PASTING INTO YOUR WEBPAGE * * */
- var disqus_shortname = '<example>'; // Required - Replace example with your forum shortname
-
- /* * * DON'T EDIT BELOW THIS LINE * * */
- (function() {
- var dsq = document.createElement('script'); dsq.type = 'text/javascript'; dsq.async = true;
- dsq.src = '//' + disqus_shortname + '.disqus.com/embed.js';
- (document.getElementsByTagName('head')[0] || document.getElementsByTagName('body')[0]).appendChild(dsq);
- })();
-</script>
-<noscript>Please enable JavaScript to view the <a href="http://disqus.com/?ref_noscript">comments powered by Disqus.</a></noscript>
- disqus -->
-<footer>Made with vim and generated by bliper in Perl.</footer>
-</body>
-</html>
diff --git a/template/page-top b/template/page-top
deleted file mode 100644
index ab3ee9d..0000000
--- a/template/page-top
+++ /dev/null
@@ -1,15 +0,0 @@
-<!DOCTYPE HTML>
-<html>
-<head>
- <meta charset="utf-8">
- <meta name="viewport" content="width=device-width">
- <title>Bliper</title>
- <link href="style.css" rel="stylesheet" type="text/css" />
-</head>
-<body>
-<div class="header">
- <a name="start"></a>
- <a href="index.html"><img class="logo" src="images/sample.png" /></a>
-%INSERTMENU%
-</div>
-<div class="container"> <!-- container begin -->
Un proyecto texto-plano.xyz
diff --git a/bin/bliper-generate.pl b/bin/bliper-generate.pl
index bc4ae51..4b80c2d 100644
--- a/bin/bliper-generate.pl
+++ b/bin/bliper-generate.pl
@@ -4,48 +4,48 @@ use strict;
use Cwd;
my $main_dir = getcwd;
-my $main_page = 'output/index.html';
-my $indir = 'main-articles'; # The input directory name
-my $outdir = 'output'; # The output directory name
-my $pagedir = 'pages'; # Individual pages directory
-my $pages_b = 'pages-b'; # Pages that do not show at menu
-my @maint = qx(cat template/main-top); # Top section for main page
-my @mainb = qx(cat template/main-bottom); # Bottom section for main page
-my @footer = qx(cat template/footer); # Footer for every page incl main
-my @paget = qx(cat template/page-top); # Top section for every page in pages/
-my @pageb = qx(cat template/page-bottom); # Bottom section for every page in pages/
-my @articlet = qx(cat template/article-top); # Top section for every article in main-articles/
-my @articleb = qx(cat template/article-bottom); # Bottom section for every article in main-articles/
+my $main_page = 'salida/index.html';
+my $indir = 'articulos'; # The input directory name
+my $outdir = 'salida'; # The salida directory name
+my $pagedir = 'paginas'; # Individual paginas directory
+my $paginas_b = 'paginas-b'; # Pages that do not show at menu
+my @maint = qx(cat plantilla/main-top); # Top section for main page
+my @mainb = qx(cat plantilla/main-bottom); # Bottom section for main page
+my @footer = qx(cat plantilla/footer); # Footer for every page incl main
+my @paget = qx(cat plantilla/page-top); # Top section for every page in paginas/
+my @pageb = qx(cat plantilla/page-bottom); # Bottom section for every page in paginas/
+my @articlet = qx(cat plantilla/article-top); # Top section for every article in articulos/
+my @articleb = qx(cat plantilla/article-bottom); # Bottom section for every article in articulos/
my $previewnum = 3; # Article number preview for frontpage
-my $cssfile = 'output/style.css';
+my $cssfile = 'salida/style.css';
-unlink glob "output/*.html"; # Remove old pages
-unlink "output/tmp"; # File which stores menu
+unlink glob "salida/*.html"; # Remove old paginas
+unlink "salida/tmp"; # File which stores menu
open (OUT, '>', "$outdir/index.html") or die $!; # Create the index.html page
print OUT @maint;
-chdir($pagedir) or die "Can't change path to $pagedir $!\n";
+chdir($pagedir) or die "No se puede acceder a $pagedir $!\n";
print "\n\t\t\tblipper (BLog In PERl) v0.1\n\n";
print "Entering " . getcwd . "\n\n";
-open (OUT, '>>', "../$outdir/tmp") or die $!; # Begin creating menu for individual pages in a file
-print OUT "<ul class=\"menu\">"; # Begin list for menu items
+open (OUT, '>>', "../$outdir/tmp") or die $!; # Crear el menú para las páginas de forma individual
+print OUT "<ul class=\"menu\">"; # Comenzar el menú para la lista de lementos
print OUT "<li><a href=\"index.html\">home</a></li>";
-my @pages = <*>; # Create individual pages
-foreach my $page (@pages) {
- print "Generating page: ";
+my @paginas = <*>; # Crear páginas individuales
+foreach my $page (@paginas) {
+ print "Generando páginas: ";
printf("%-30s", $page);
my @array = qx(cat $page);
my $html = qx(Markdown.pl $page);
$page =~ s/\.[^\.]*$//;
- print "\t==> output page:\t" . "../$outdir/$page.html\n";
+ print "\t==> Sacando páginas:\t" . "../$outdir/$page.html\n";
open (OUT, '>', "../$outdir/$page.html") or die $!;
print OUT @paget;
print OUT $html;
print OUT @pageb;
close OUT;
- open (OUT, '>>', "../$outdir/tmp") or die $!; # Append page links to tmp file
+ open (OUT, '>>', "../$outdir/tmp") or die $!; # Adjuntar los enlaces de la página a un fichero temporal
print OUT "<li><a href=\"$page.html\">$page</a></li>";
}
@@ -53,37 +53,37 @@ print OUT "</ul>";
print OUT "<br>";
close OUT or die $!;
-chdir($main_dir) or die "Can't change path to $main_dir $!\n";
-# open (OUT, '>>', "$outdir/index.html") or die $!; # Create the index.html page
+chdir($main_dir) or die "No se puede acceder a to $main_dir $!\n";
+# open (OUT, '>>', "$outdir/index.html") or die $!; # Crea la página index.html
# print OUT "<p class=\"latart\">Latest articles:</p>";
# close OUT or die $!;
-print "\nIndividual page generation completed. ";
-chdir($indir) or die "Can't change path to $indir $!\n";
-print "\nEntering " . getcwd . "\n\n";
+print "\nCompletada la generación de páginas individuales. ";
+chdir($indir) or die "No se puede acceder a $indir $!\n";
+print "\nAccediendo a" . getcwd . "\n\n";
my @files = <*>;
@files = reverse @files;
my $i = 0;
-foreach my $file (@files) { # Read each file(post) from indir, cat to $outdir/$file.html
- print "Processing file: ";
+foreach my $file (@files) { # Lee cada entrada file(post) desde el direcotiro de entrada, lo redirige a $outdir/$file.html
+ print "Procesando fichero: ";
printf ("%-30s", $file);
my $array = qx(cat $file);
my $html = qx(Markdown.pl $file);
$file =~ s/\.[^\.]*$//;
- print "\t==> output file:\t" . "../$outdir/$file.html\n";
+ print "\t==> Sacando fichero :\t" . "../$outdir/$file.html\n";
open (OUT, '>', "../$outdir/$file.html") or die $!;
print OUT @articlet;
- print OUT $html; # Append content
+ print OUT $html; # Adjuntar contenido
print OUT @articleb;
close OUT;
- my @preview_array = split(/\n{2,}/, $html); # Pull title and first paragraph from article.
- $preview_array[0] =~ s/h1>/h3>/g; # Change h1 to h3 for the index page.
+ my @preview_array = split(/\n{2,}/, $html); # Recoge el título del artículo.
+ $preview_array[0] =~ s/h1>/h3>/g; # Cambia h1 to h3 por la página principal.
$preview_array[0] =~ s/<h3>/<a href=\"$file.html\"><h3>/g;
$preview_array[0] =~ s/<\/h3>/<\/h3><\/a>/g;
- if ($i < $previewnum) { # Append links to stories in index.html
+ if ($i < $previewnum) { # Adjunta enlaces a historias en index.html
open (OUT, '>>', "../$outdir/index.html") or die $!;
print OUT "<div class=\"preview\">
$preview_array[0]
@@ -97,32 +97,32 @@ foreach my $file (@files) { # Read each file(post) from indir, cat to $outdi
$i++;
}
-chdir($main_dir) or die "Can't change path to $main_dir $!\n";
-print "\nArticle generation completed. ";
-chdir($pages_b) or die "Can't change path to $indir $!\n";
-print "\nEntering " . getcwd . "\n\n";
+chdir($main_dir) or die "No se puede acceder a $main_dir $!\n";
+print "\nGeneración de artículos completada. ";
+chdir($paginas_b) or die "No se puede acceder a $indir $!\n";
+print "\nEntrando a" . getcwd . "\n\n";
-my @ind_pages = <*>;
-foreach my $file (@ind_pages) { # Read each page that we do not want to add in our menu
- print "Processing pages:";
+my @ind_paginas = <*>;
+foreach my $file (@ind_paginas) { # Lee cada página que no se quiere añadir al menú.
+ print "Procesando páginas:";
printf ("%-30s", $file);
my @array = qx(cat $file);
- my $html = qx(Markdown.pl $file); # Markdown to html
+ my $html = qx(Markdown.pl $file); # Markdown a html
$file =~ s/\.[^\.]*$//;
- print "\t==> output file:\t" . "../$outdir/$file.html\n";
+ print "\t==> Sacando file:\t" . "../$outdir/$file.html\n";
open (OUT, '>', "../$outdir/$file.html") or die $!;
print OUT @articlet;
- print OUT $html; # Append content
+ print OUT $html; # Añadir contenido
print OUT @articleb;
close OUT;
}
-open (OUT, '>>', "../$outdir/index.html") or die $!; # Close all tags in index.html
+open (OUT, '>>', "../$outdir/index.html") or die $!; # Cierra todas las etiquetas en index.html
print OUT @mainb;
print OUT @footer;
close OUT;
-print "\nPages in pages_b/ generation completed. ";
-print "\nLeaving " . getcwd . "\n";
-chdir($main_dir) or die "Can't change path to $main_dir $!\n";
-print "Site generation completed. Files are in output/ dir.\n";
+print "\nLas páginas de salida/ han sdo generadas.";
+print "\nSaliendo de" . getcwd . "\n";
+chdir($main_dir) or die "No se puede acceder a $main_dir $!\n";
+print "Los ficheros se han generado al completo. Estan en salida/.\n";